@@ -25,7 +25,15 @@
 #include "oobs-session.h"
 #include "oobs-session-private.h"
 
+/**
+ * SECTION:oobs-object
+ * @title: OobsObject
+ * @short_description: Base object for all configuration objects
+ * @see_also: #OobsList
+ **/
+
 #define OOBS_OBJECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), OOBS_TYPE_OBJECT, OobsObjectPrivate))
+#define POLKIT_ACTION "org.freedesktop.systemtoolsbackends.set"
 
 typedef struct _OobsObjectPrivate OobsObjectPrivate;
 typedef struct _OobsObjectAsyncCallbackData OobsObjectAsyncCallbackData;
@@ -70,6 +78,8 @@ static void oobs_object_get_property (GObject       *object,
 				      GValue        *value,
 				      GParamSpec    *pspec);
 
+static const gchar * oobs_object_real_get_authentication_action (OobsObject *object);
+
 static void connect_object_to_session (OobsObject *object);
 
 enum
@@ -102,9 +112,7 @@ oobs_object_class_init (OobsObjectClass *class)
   object_class->set_property = oobs_object_set_property;
   object_class->finalize     = oobs_object_finalize;
 
-  class->commit   = NULL;
-  class->update   = NULL;
-  class->changed  = NULL;
+  class->get_authentication_action = oobs_object_real_get_authentication_action;
 
   dbus_connection_quark = g_quark_from_static_string ("oobs-dbus-connection");
 
@@ -209,6 +217,18 @@ oobs_object_constructor (GType                  type,
   return object;
 }
 
+static gboolean
+object_changed_idle (gpointer data)
+{
+  OobsObject *object;
+
+  object = OOBS_OBJECT (data);
+
+  g_signal_emit (object, object_signals [CHANGED], 0);
+
+  return FALSE;
+}
+
 static DBusHandlerResult
 changed_signal_filter (DBusConnection *connection,
 		       DBusMessage    *message,
@@ -222,7 +242,7 @@ changed_signal_filter (DBusConnection *connection,
 
   if (dbus_message_is_signal (message, priv->method, "changed") &&
       dbus_message_has_path (message, priv->path))
-    g_signal_emit (object, object_signals [CHANGED], 0);
+    g_idle_add (object_changed_idle, object);
 
   /* we want the rest of the objects of
    * the same type to get the signal too
@@ -300,6 +320,12 @@ oobs_object_get_property (GObject      *object,
     }
 }
 
+static const gchar *
+oobs_object_real_get_authentication_action (OobsObject *object)
+{
+  return POLKIT_ACTION;
+}
+
 DBusMessage*
 _oobs_object_get_dbus_message (OobsObject *object)
 {
@@ -609,7 +635,6 @@ oobs_object_update (OobsObject *object)
   if (reply)
     {
       result = update_object_from_message (object, reply);
-      g_signal_emit (object, object_signals [UPDATED], 0);
       dbus_message_unref (reply);
     }
 
@@ -719,3 +744,23 @@ oobs_object_ensure_update (OobsObject *object)
   else
     oobs_object_update (object);
 }
+
+/**
+ * oobs_object_get_authentication_action:
+ * @object: An #OobsObject.
+ *
+ * Returns the PolicyKit action required to be able to modify this object configuration.
+ *
+ * Return Value: string defining the PolicyKit action
+ *               required to modify objects in the session.
+ **/
+G_CONST_RETURN gchar *
+oobs_object_get_authentication_action (OobsObject *object)
+{
+  OobsObjectClass *class;
+
+  g_return_val_if_fail (OOBS_IS_OBJECT (object), NULL);
+
+  class = OOBS_OBJECT_GET_CLASS (object);
+  return class->get_authentication_action (object);
+}
