@@ -33,6 +33,13 @@
 #include "oobs-group.h"
 #include "utils.h"
 
+/**
+ * SECTION:oobs-usersconfig
+ * @title: OobsUsersConfig
+ * @short_description: Object that represents users configuration
+ * @see_also: #OobsUser
+ **/
+
 #define USERS_CONFIG_REMOTE_OBJECT "UsersConfig"
 #define OOBS_USERS_CONFIG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), OOBS_TYPE_USERS_CONFIG, OobsUsersConfigPrivate))
 
@@ -359,7 +366,9 @@ create_dbus_struct_from_user (OobsUser        *user,
 		"other-data", &other_data,
 		NULL);
 
-  g_return_val_if_fail ((login && password), FALSE);
+  /* Login is the only required field,
+   * since home dir, password and shell are allowed to be empty (see man 5 passwd) */
+  g_return_val_if_fail (login, FALSE);
 
   group = oobs_user_get_main_group (user);
   gid = oobs_group_get_gid (group);
